@@ -86,7 +86,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x54c00
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -139,9 +139,22 @@
 #else
 #  define KCOMPLETION_DEPRECATED_VERSION_5_66(text)
 #endif
+
+#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x55100
+#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text)
+#endif
 #define KCOMPLETION_DEPRECATED_VERSION_4(minor, text)      KCOMPLETION_DEPRECATED_VERSION_4_##minor(text)
 #define KCOMPLETION_DEPRECATED_VERSION_5(minor, text)      KCOMPLETION_DEPRECATED_VERSION_5_##minor(text)
 #define KCOMPLETION_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION(major, minor, text)
+#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCOMPLETION_EXPORT_H */
